@@ -207,7 +207,7 @@ static void ReadPSInfo(const ImageInfo *image_info,Image *image,
 {
 #define BeginDocument  "BeginDocument:"
 #define EndDocument  "EndDocument:"
-#define PostscriptLevel  "!PS-"
+#define PostscriptLevel  "PS-"
 #define ImageData  "ImageData:"
 #define DocumentProcessColors  "DocumentProcessColors:"
 #define CMYKCustomColor  "CMYKCustomColor:"
@@ -229,6 +229,7 @@ static void ReadPSInfo(const ImageInfo *image_info,Image *image,
     c;
 
   MagickBooleanType
+    new_line,
     skip;
 
   MagickByteBuffer
@@ -290,6 +291,7 @@ static void ReadPSInfo(const ImageInfo *image_info,Image *image,
   *version='\0';
   spotcolor=0;
   skip=MagickFalse;
+  new_line=MagickTrue;
   (void) memset(&buffer,0,sizeof(buffer));
   buffer.image=image;
   for (c=ReadMagickByteBuffer(&buffer); c != EOF; c=ReadMagickByteBuffer(&buffer))
@@ -303,8 +305,23 @@ static void ReadPSInfo(const ImageInfo *image_info,Image *image,
       }
       case '\n':
       case '\r':
+        new_line=MagickTrue;
+        continue;
       case '%':
-        break;
+      {
+        if (new_line == MagickFalse)
+          continue;
+        new_line=MagickFalse;
+        c=ReadMagickByteBuffer(&buffer);
+        if ((c == '%') || (c == '!'))
+          break;
+        if (c == 'B')
+          {
+            buffer.offset--;
+            break;
+          }
+        continue;
+      }
       default:
         continue;
     }
@@ -391,18 +408,21 @@ static void ReadPSInfo(const ImageInfo *image_info,Image *image,
         /*
           Read ICC profile.
         */
-        ps_info->icc_profile=AcquireStringInfo(MagickPathExtent);
-        datum=GetStringInfoDatum(ps_info->icc_profile);
-        for (i=0; (c=ProfileInteger(&buffer,hex_digits)) != EOF; i++)
-        {
-          if (i >= (ssize_t) GetStringInfoLength(ps_info->icc_profile))
+        if (SkipMagickByteBufferUntil(&buffer,'\n') != MagickFalse)
+          {
+            ps_info->icc_profile=AcquireStringInfo(MagickPathExtent);
+            datum=GetStringInfoDatum(ps_info->icc_profile);
+            for (i=0; (c=ProfileInteger(&buffer,hex_digits)) != EOF; i++)
             {
-              SetStringInfoLength(ps_info->icc_profile,(size_t) i << 1);
-              datum=GetStringInfoDatum(ps_info->icc_profile);
+              if (i >= (ssize_t) GetStringInfoLength(ps_info->icc_profile))
+                {
+                  SetStringInfoLength(ps_info->icc_profile,(size_t) i << 1);
+                  datum=GetStringInfoDatum(ps_info->icc_profile);
+                }
+              datum[i]=(unsigned char) c;
             }
-          datum[i]=(unsigned char) c;
-        }
-        SetStringInfoLength(ps_info->icc_profile,(size_t) i+1);
+            SetStringInfoLength(ps_info->icc_profile,(size_t) i+1);
+          }
         continue;
       }
     if ((ps_info->photoshop_profile == (StringInfo *) NULL) &&
@@ -425,17 +445,20 @@ static void ReadPSInfo(const ImageInfo *image_info,Image *image,
         if ((MagickSizeType) extent > GetBlobSize(image))
           continue;
         length=(size_t) extent;
-        ps_info->photoshop_profile=AcquireStringInfo(length+1U);
-        q=GetStringInfoDatum(ps_info->photoshop_profile);
-        while (extent > 0)
-        {
-          c=ProfileInteger(&buffer,hex_digits);
-          if (c == EOF)
-            break;
-          *q++=(unsigned char) c;
-          extent-=MagickMin(extent,2);
-        }
-        SetStringInfoLength(ps_info->photoshop_profile,length);
+        if (SkipMagickByteBufferUntil(&buffer,'\n') != MagickFalse)
+          {
+            ps_info->photoshop_profile=AcquireStringInfo(length+1U);
+            q=GetStringInfoDatum(ps_info->photoshop_profile);
+            while (extent > 0)
+            {
+              c=ProfileInteger(&buffer,hex_digits);
+              if (c == EOF)
+                break;
+              *q++=(unsigned char) c;
+              extent-=MagickMin(extent,2);
+            }
+            SetStringInfoLength(ps_info->photoshop_profile,length);
+          }
         continue;
       }
     if (image_info->page != (char *) NULL)
@@ -509,7 +532,6 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
     command[MagickPathExtent],
     *density,
     filename[MagickPathExtent],
-    geometry[MagickPathExtent],
     input_filename[MagickPathExtent],
     message[MagickPathExtent],
     *options,
@@ -626,10 +648,9 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
   if ((fabs(info.bounds.x2-info.bounds.x1) >= MagickEpsilon) &&
       (fabs(info.bounds.y2-info.bounds.y1) >= MagickEpsilon))
     {
-      (void) FormatLocaleString(geometry,MagickPathExtent,"%gx%g%+.15g%+.15g",
-        info.bounds.x2-info.bounds.x1,info.bounds.y2-info.bounds.y1,
-        info.bounds.x1,info.bounds.y1);
-      (void) SetImageProperty(image,"ps:HiResBoundingBox",geometry,exception);
+      (void) FormatImageProperty(image,"ps:HiResBoundingBox",
+        "%gx%g%+.15g%+.15g",info.bounds.x2-info.bounds.x1,info.bounds.y2-
+        info.bounds.y1,info.bounds.x1,info.bounds.y1);
       page.width=(size_t) ((ssize_t) ceil((double) ((info.bounds.x2-
         info.bounds.x1)*resolution.x/delta.x)-0.5));
       page.height=(size_t) ((ssize_t) ceil((double) ((info.bounds.y2-
